@@ -128,7 +128,7 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : QDialo
 	namingFormatValidLabel->setPixmap(validPixmap);
 	gridLayout->addWidget(namingFormatValidLabel, 4,2);
 
-	gridLayout->addWidget(new QLabel(i18n("Action after recording finishes.")),	5, 0);
+	gridLayout->addWidget(new QLabel(i18n("Action after recording finishes:")),	5, 0);
 
 	actionAfterRecordingLineEdit = new QLineEdit(widget);
 	actionAfterRecordingLineEdit->setText(manager->getActionAfterRecording());
@@ -1052,7 +1052,7 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 	higherVoltageBox->setToolTip(i18n("On some DVB devices, there's an extra control that allows to increase the \n"
 		"voltage sent to LNBf, in order to compensate for cabling loss. This tri-state\n"
 		"button defaults to not use it. It may be set to:\n"
-		"- normal mode (unckecked);\n"
+		"- normal mode (unchecked);\n"
 		"- higher voltage mode (checked);\n"
 		"- tristate (don't send the control)."));
 	layout->addWidget(higherVoltageBox, 1, 1);
@@ -1081,7 +1081,7 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 			config = createConfig(lnbNumber);
 		}
 
-		QPushButton *pushButton = new QPushButton(i18n("LNB %1 Settings", lnbNumber + 2),
+		QPushButton *pushButton = new QPushButton(i18n("LNB %1 Settings", lnbNumber + 1),
 							  parent);
 		if (lnbNumber > 0)
 			connect(this, &DvbSConfigObject::setDiseqcVisible,
@@ -1089,7 +1089,7 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 		else
 			connect(this, &DvbSConfigObject::setFirstLnbVisible,
 				pushButton, &QPushButton::setVisible);
-		layout->addWidget(pushButton, lnbNumber + 2, 0);
+		layout->addWidget(pushButton, lnbNumber + 3, 0);
 
 		QComboBox *comboBox = new QComboBox(parent);
 		comboBox->addItem(i18n("No Source"));
@@ -1539,7 +1539,7 @@ void DvbSLnbConfigObject::configure()
 
 	for (i = 0; i < size; i++) {
 		struct lnbSat lnb = device->getLnbSatModels().at(i);
-		QRadioButton *radioButton = new QRadioButton(lnb.name, mainWidget);
+		QRadioButton *radioButton = new QRadioButton(i18nd("libdvbv5", qPrintable(lnb.name)), mainWidget);
 		mainLayout->addWidget(radioButton);
 		lnbSelectionGroup->addButton(radioButton, i + 1);
 		gridLayout->addWidget(radioButton, i % ((size + 1) / 2), i / ((size + 1) / 2));
@@ -1591,7 +1591,7 @@ void DvbSLnbConfigObject::configure()
 	gridLayout->addWidget(lowRangeLabel, 3, 4, 1, 2);
 
 	highRangeLabel = new QLabel(mainWidget);
-	gridLayout->addWidget(highRangeLabel, 4, 5, 1, 2);
+	gridLayout->addWidget(highRangeLabel, 4, 4, 1, 2);
 
 	selectType(currentType);
 
