@@ -30,6 +30,7 @@ extern "C" {
 }
 
 #include <QFile>
+#include <QCheckBox>
 #include <QMessageLogger>
 #include <QRegularExpressionMatch>
 #include <Solid/Device>
@@ -279,27 +280,15 @@ bool DvbLinuxDevice::acquire()
 	return true;
 }
 
-bool DvbLinuxDevice::setTone(SecTone tone)
+bool DvbLinuxDevice::setHighVoltage(int higherVoltage)
 {
 	Q_ASSERT(dvbv5_parms);
 
-	if (dvb_fe_sec_tone(dvbv5_parms,
-		  (tone == ToneOn) ? SEC_TONE_ON : SEC_TONE_OFF) != 0) {
-		qCWarning(logDev, "ioctl FE_SET_TONE failed for frontend %s", qPrintable(frontendPath));
+	if ((Qt::CheckState)higherVoltage == Qt::PartiallyChecked)
+		return true;
+
+	if (dvb_fe_lnb_high_voltage(dvbv5_parms, higherVoltage ? 1 : 0))
 		return false;
-	}
-
-	return true;
-}
-
-bool DvbLinuxDevice::setVoltage(SecVoltage voltage)
-{
-	Q_ASSERT(dvbv5_parms);
-
-	if (dvb_fe_lnb_high_voltage(dvbv5_parms, voltage == Voltage18V) != 0) {
-		qCWarning(logDev, "ioctl FE_SET_VOLTAGE failed for frontend %s", qPrintable(frontendPath));
-		return false;
-	}
 
 	return true;
 }
