@@ -26,6 +26,7 @@
 #include <QStandardPaths>
 
 #include "../ensurenopendingoperation.h"
+#include "../iso-codes.h"
 #include "dvbdevice.h"
 #include "dvbepg.h"
 #include "dvbepg_p.h"
@@ -82,7 +83,7 @@ DvbEpgModel::DvbEpgModel(DvbManager *manager_, QObject *parent) : QObject(parent
 	QDataStream stream(&file);
 	stream.setVersion(QDataStream::Qt_4_4);
 	DvbRecordingModel *recordingModel = manager->getRecordingModel();
-	bool hasRecordingKey = true, hasParental = true;
+	bool hasRecordingKey = true, hasParental = true, hasMultilang = true;
 	int version;
 	stream >> version;
 
@@ -90,7 +91,9 @@ DvbEpgModel::DvbEpgModel(DvbManager *manager_, QObject *parent) : QObject(parent
 		hasRecordingKey = false;
 	} else if (version == 0x79cffd36) {
 		hasParental = false;
-	} else if (version != 0x140c37b5) {
+	} else if (version == 0x140c37b5) {
+		hasMultilang = false;
+	} else if (version != 0x20171112) {
 		qCWarning(logEpg, "Wrong DB version for: %s", qPrintable(file.fileName()));
 		return;
 	}
@@ -103,9 +106,37 @@ DvbEpgModel::DvbEpgModel(DvbManager *manager_, QObject *parent) : QObject(parent
 		stream >> entry.begin;
 		entry.begin = entry.begin.toUTC();
 		stream >> entry.duration;
-		stream >> entry.title;
-		stream >> entry.subheading;
-		stream >> entry.details;
+
+		if (hasMultilang) {
+			int i, count;
+
+			stream >> count;
+
+			for (i = 0; i < count; i++) {
+				QString code;
+
+				DvbEpgLangEntry langEntry;
+				stream >> code;
+				stream >> langEntry.title;
+				stream >> langEntry.subheading;
+				stream >> langEntry.details;
+
+				entry.langEntry[code] = langEntry;
+
+				if (!langEntry.title.isEmpty() && !manager->languageCodes.contains(code))
+					manager->languageCodes[code] = true;
+			}
+
+
+		} else {
+			DvbEpgLangEntry langEntry;
+
+			stream >> langEntry.title;
+			stream >> langEntry.subheading;
+			stream >> langEntry.details;
+
+			entry.langEntry[FIRST_LANG] = langEntry;
+		}
 
 		if (hasRecordingKey) {
 			SqlKey recordingKey;
@@ -117,14 +148,14 @@ DvbEpgModel::DvbEpgModel(DvbManager *manager_, QObject *parent) : QObject(parent
 		}
 
 		if (hasParental) {
-			unsigned tmp;
+			unsigned type;
 
-			stream >> tmp;
+			stream >> type;
 			stream >> entry.content;
 			stream >> entry.parental;
 
-			if (tmp <= DvbEpgEntry::EitLast)
-				entry.type = DvbEpgEntry::EitType(tmp);
+			if (type <= DvbEpgEntry::EitLast)
+				entry.type = DvbEpgEntry::EitType(type);
 			else
 				entry.type = DvbEpgEntry::EitActualTsSchedule;
 		}
@@ -157,7 +188,7 @@ DvbEpgModel::~DvbEpgModel()
 
 	QDataStream stream(&file);
 	stream.setVersion(QDataStream::Qt_4_4);
-	int version = 0x140c37b5;
+	int version = 0x20171112;
 	stream << version;
 
 	foreach (const DvbSharedEpgEntry &entry, entries) {
@@ -170,9 +201,23 @@ DvbEpgModel::~DvbEpgModel()
 		stream << entry->channel->name;
 		stream << entry->begin;
 		stream << entry->duration;
-		stream << entry->title;
-		stream << entry->subheading;
-		stream << entry->details;
+
+		stream << entry->langEntry.size();
+
+		QHashIterator<QString, DvbEpgLangEntry> i(entry->langEntry);
+
+		while (i.hasNext()) {
+			i.next();
+
+			stream << i.key();
+
+			DvbEpgLangEntry langEntry = i.value();
+
+			stream << langEntry.title;
+			stream << langEntry.subheading;
+			stream << langEntry.details;
+		}
+
 		stream << recordingKey.sqlKey;
 		stream << int(entry->type);
 		stream << entry->content;
@@ -231,7 +276,9 @@ void DvbEpgModel::Debug(QString text, const DvbSharedEpgEntry &entry)
 	QDateTime begin = entry->begin.toLocalTime();
 	QTime end = entry->begin.addSecs(QTime(0, 0, 0).secsTo(entry->duration)).toLocalTime().time();
 
-	qCDebug(logEpg, "event %s: type %d, from %s to %s: %s: %s: %s : %s", qPrintable(text), entry->type, qPrintable(QLocale().toString(begin, QLocale::ShortFormat)), qPrintable(QLocale().toString(end)), qPrintable(entry->title), qPrintable(entry->subheading), qPrintable(entry->details), qPrintable(entry->content));
+	qCDebug(logEpg, "event %s: type %d, from %s to %s: %s: %s: %s : %s",
+		qPrintable(text), entry->type, qPrintable(QLocale().toString(begin, QLocale::ShortFormat)), qPrintable(QLocale().toString(end)),
+		qPrintable(entry->title()), qPrintable(entry->subheading()), qPrintable(entry->details()), qPrintable(entry->content));
 }
 
 DvbSharedEpgEntry DvbEpgModel::addEntry(const DvbEpgEntry &entry)
@@ -276,10 +323,18 @@ DvbSharedEpgEntry DvbEpgModel::addEntry(const DvbEpgEntry &entry)
 			break;
 		}
 		// New event data for the same event
-		if (existingEntry->details.isEmpty() && !entry.details.isEmpty()) {
+		if (existingEntry->details(FIRST_LANG).isEmpty() && !entry.details(FIRST_LANG).isEmpty()) {
 			emit entryAboutToBeUpdated(existingEntry);
-			const_cast<DvbEpgEntry *>(existingEntry.constData())->details =
-				entry.details;
+
+			QHashIterator<QString, DvbEpgLangEntry> i(entry.langEntry);
+
+			while (i.hasNext()) {
+				i.next();
+
+				DvbEpgLangEntry langEntry = i.value();
+
+				const_cast<DvbEpgEntry *>(existingEntry.constData())->langEntry[i.key()].details = langEntry.details;
+			}
 			emit entryUpdated(existingEntry);
 			Debug("updated", existingEntry);
 		}
@@ -290,11 +345,19 @@ DvbSharedEpgEntry DvbEpgModel::addEntry(const DvbEpgEntry &entry)
 		DvbSharedEpgEntry existingEntry = entries.value(DvbEpgEntryId(&entry));
 
 		if (existingEntry.isValid()) {
-			if (existingEntry->details.isEmpty() && !entry.details.isEmpty()) {
+			if (existingEntry->details(FIRST_LANG).isEmpty() && !entry.details(FIRST_LANG).isEmpty()) {
 				// needed for atsc
 				emit entryAboutToBeUpdated(existingEntry);
-				const_cast<DvbEpgEntry *>(existingEntry.constData())->details =
-					entry.details;
+
+				QHashIterator<QString, DvbEpgLangEntry> i(entry.langEntry);
+
+				while (i.hasNext()) {
+					i.next();
+
+					DvbEpgLangEntry langEntry = i.value();
+
+					const_cast<DvbEpgEntry *>(existingEntry.constData())->langEntry[i.key()].details = langEntry.details;
+				}
 				emit entryUpdated(existingEntry);
 				Debug("updated2", existingEntry);
 			}
@@ -341,7 +404,7 @@ void DvbEpgModel::scheduleProgram(const DvbSharedEpgEntry &entry, int extraSecon
 	if (!entry->recording.isValid()) {
 		DvbRecording recording;
 		recording.priority = priority;
-		recording.name = entry->title;
+		recording.name = entry->title(manager->currentEpgLanguage);
 		recording.channel = entry->channel;
 		recording.begin = entry->begin.addSecs(-extraSecondsBefore);
 		recording.beginEPG = entry->begin;
@@ -350,9 +413,9 @@ void DvbEpgModel::scheduleProgram(const DvbSharedEpgEntry &entry, int extraSecon
 		recording.durationEPG =
 			entry->duration;
 		recording.subheading =
-			entry->subheading;
+			entry->subheading(manager->currentEpgLanguage);
 		recording.details =
-			entry->details;
+			entry->details(manager->currentEpgLanguage);
 		recording.disabled = false;
 		const_cast<DvbEpgEntry *>(entry.constData())->recording =
 			manager->getRecordingModel()->addRecording(recording, checkForRecursion);
@@ -530,9 +593,10 @@ DvbEpgModel::Iterator DvbEpgModel::removeEntry(Iterator it)
 	return entries.erase(it);
 }
 
-DvbEpgFilter::DvbEpgFilter(DvbManager *manager, DvbDevice *device_,
+DvbEpgFilter::DvbEpgFilter(DvbManager *manager_, DvbDevice *device_,
 	const DvbSharedChannel &channel) : device(device_)
 {
+	manager = manager_;
 	source = channel->source;
 	transponder = channel->transponder;
 	device->addSectionFilter(0x12, this);
@@ -835,10 +899,15 @@ QString DvbEpgFilter::getParental(DvbParentalRatingDescriptor &descriptor)
 		code.append(QChar(entry.languageCode2()));
 		code.append(QChar(entry.languageCode3()));
 
+		QString country;
+		IsoCodes::getCountry(code, &country);
+		if (country.isEmpty())
+			country = code;
+
 		// Rating from 0x10 to 0xff are broadcaster's specific
 		if (entry.rating() == 0) {
 			// xgettext:no-c-format
-			parental += i18n("Country %1: not rated\n", code);
+			parental += i18n("Country %1: not rated\n", country);
 		} else if (entry.rating() < 0x10) {
 			if (code == "BRA" && transponder.getTransmissionType() == DvbTransponderBase::IsdbT) {
 				unsigned int rating = entry.rating();
@@ -862,17 +931,51 @@ QString DvbEpgFilter::getParental(DvbParentalRatingDescriptor &descriptor)
 
 				QString ratingStr = i18n(braRating[entry.rating()]);
 				// xgettext:no-c-format
-				parental += i18n("Country %1: rating: %2%3\n", code, ratingStr, GenStr);
+				parental += i18n("Country %1: rating: %2%3\n", country, ratingStr, GenStr);
 			} else {
 				// xgettext:no-c-format
-				parental += i18n("Country %1: rating: %2 years.\n", code, entry.rating() + 3);
+				parental += i18n("Country %1: rating: %2 years.\n", country, entry.rating() + 3);
 			}
 		}
 	}
-
 	return parental;
 }
 
+DvbEpgLangEntry *DvbEpgFilter::getLangEntry(DvbEpgEntry &epgEntry,
+					    int code1, int code2, int code3,
+					    bool add_code,
+					    QString *code_)
+{
+	DvbEpgLangEntry *langEntry;
+	QString code;
+
+	if (!code1 || code1 == 0x20)
+		code = FIRST_LANG;
+	else {
+		code.append(QChar(code1));
+		code.append(QChar(code2));
+		code.append(QChar(code3));
+		code = code.toUpper();
+	}
+	if (code_)
+		code_ = new QString(code);
+
+	if (!epgEntry.langEntry.contains(code)) {
+		DvbEpgLangEntry e;
+		epgEntry.langEntry.insert(code, e);
+		if (add_code) {
+			if (!manager->languageCodes.contains(code)) {
+				manager->languageCodes[code] = true;
+				emit epgModel->languageAdded(code);
+			}
+		}
+	}
+	langEntry = &epgEntry.langEntry[code];
+
+	return langEntry;
+}
+
+
 void DvbEpgFilter::processSection(const char *data, int size)
 {
 	unsigned char tableId = data[0];
@@ -911,6 +1014,7 @@ void DvbEpgFilter::processSection(const char *data, int size)
 
 	for (DvbEitSectionEntry entry = eitSection.entries(); entry.isValid(); entry.advance()) {
 		DvbEpgEntry epgEntry;
+		DvbEpgLangEntry *langEntry;
 
 		if (tableId == 0x4e)
 			epgEntry.type = DvbEpgEntry::EitActualTsPresentFollowing;
@@ -929,10 +1033,10 @@ void DvbEpgFilter::processSection(const char *data, int size)
 		 */
 		if (channel->transponder.getTransmissionType() == DvbTransponderBase::IsdbT)
 			epgEntry.begin = QDateTime(QDate::fromJulianDay(entry.startDate() + 2400001),
-					           bcdToTime(entry.startTime()), Qt::OffsetFromUTC, -10800).toUTC();
+						   bcdToTime(entry.startTime()), Qt::OffsetFromUTC, -10800).toUTC();
 		else
 			epgEntry.begin = QDateTime(QDate::fromJulianDay(entry.startDate() + 2400001),
-					           bcdToTime(entry.startTime()), Qt::UTC);
+						   bcdToTime(entry.startTime()), Qt::UTC);
 		epgEntry.duration = bcdToTime(entry.duration());
 
 		for (DvbDescriptor descriptor = entry.descriptors(); descriptor.isValid();
@@ -945,8 +1049,14 @@ void DvbEpgFilter::processSection(const char *data, int size)
 					break;
 				}
 
-				epgEntry.title += eventDescriptor.eventName();
-				epgEntry.subheading += eventDescriptor.text();
+				langEntry = getLangEntry(epgEntry,
+					     eventDescriptor.languageCode1(),
+					     eventDescriptor.languageCode2(),
+					     eventDescriptor.languageCode3());
+
+				langEntry->title += eventDescriptor.eventName();
+				langEntry->subheading += eventDescriptor.text();
+
 				break;
 			    }
 			case 0x4e: {
@@ -956,7 +1066,11 @@ void DvbEpgFilter::processSection(const char *data, int size)
 					break;
 				}
 
-				epgEntry.details += eventDescriptor.text();
+				langEntry = getLangEntry(epgEntry,
+					     eventDescriptor.languageCode1(),
+					     eventDescriptor.languageCode2(),
+					     eventDescriptor.languageCode3());
+				langEntry->details += eventDescriptor.text();
 				break;
 			    }
 			case 0x54: {
@@ -1150,7 +1264,16 @@ void AtscEpgFilter::processEitSection(const char *data, int size)
 		epgEntry.channel = channel;
 		epgEntry.begin = baseDateTime.addSecs(eitEntry.startTime());
 		epgEntry.duration = QTime(0, 0, 0).addSecs(eitEntry.duration());
-		epgEntry.title = eitEntry.title();
+
+
+		DvbEpgLangEntry *langEntry;
+
+		if (epgEntry.langEntry.contains(FIRST_LANG))
+			langEntry = &epgEntry.langEntry[FIRST_LANG];
+		else
+			langEntry = new(DvbEpgLangEntry);
+
+		langEntry->title = eitEntry.title();
 
 		quint32 id = ((quint32(fakeChannel.networkId) << 16) | quint32(eitEntry.eventId()));
 		DvbSharedEpgEntry entry = epgEntries.value(id);
@@ -1182,9 +1305,17 @@ void AtscEpgFilter::processEttSection(const char *data, int size)
 	if (entry.isValid()) {
 		QString details = ettSection.text();
 
-		if (entry->details != details) {
+		if (entry->details() != details) {
 			DvbEpgEntry modifiedEntry = *entry;
-			modifiedEntry.details = details;
+
+			DvbEpgLangEntry *langEntry;
+
+			if (modifiedEntry.langEntry.contains(FIRST_LANG))
+				langEntry = &modifiedEntry.langEntry[FIRST_LANG];
+			else
+				langEntry = new(DvbEpgLangEntry);
+
+			langEntry->details = details;
 			entry = epgModel->addEntry(modifiedEntry);
 			epgEntries.insert(id, entry);
 		}
