@@ -121,6 +121,8 @@ public:
 	QStringList getScanSources(TransmissionType type);
 	QString getAutoScanSource(const QString &source) const;
 	QList<DvbTransponder> getTransponders(DvbDevice *device, const QString &source);
+	QHash<QString, bool> languageCodes;
+	QString currentEpgLanguage;
 	bool updateScanData(const QByteArray &data);
 
 	QString getRecordingFolder() const;
