@@ -34,6 +34,7 @@
 #include <QDesktopWidget>
 #include <QFileDialog>
 #include <QHoverEvent>
+#include <QWheelEvent>
 #include <QInputDialog>
 #include <QLoggingCategory>
 #include <QMainWindow>
@@ -122,7 +123,7 @@ StartTab::StartTab(MainWindow *mainWindow)
 	connect(button, SIGNAL(clicked()), mainWindow, SLOT(openAudioCd()));
 	gridLayout->addWidget(button, 0, 1);
 
-	button = addShortcut(i18n("&3 Play Video CD"), QIcon::fromTheme(QLatin1String("media-optical"), QIcon(":media-optical")), this);
+	button = addShortcut(i18n("&3 Play Video CD"), QIcon::fromTheme(QLatin1String("media-optical"), QIcon(":media-optical-video")), this);
 	button->setShortcut(Qt::Key_3);
 	button->setWhatsThis(i18n("Start playing a Video CD. It assumes that the CD is already there at the CD drive"));
 	connect(button, SIGNAL(clicked()), mainWindow, SLOT(openVideoCd()));
@@ -226,7 +227,7 @@ void MainWindow::run()
 	connect(action, SIGNAL(triggered(bool)), this, SLOT(openAudioCd()));
 	menu->addAction(collection->addAction(QLatin1String("file_play_audiocd"), action));
 
-	action = new QAction(QIcon::fromTheme(QLatin1String("media-optical"), QIcon(":media-optical")), i18n("Play Video CD"), collection);
+	action = new QAction(QIcon::fromTheme(QLatin1String("media-optical"), QIcon(":media-optical-video")), i18n("Play Video CD"), collection);
 	connect(action, SIGNAL(triggered(bool)), this, SLOT(openVideoCd()));
 	menu->addAction(collection->addAction(QLatin1String("file_play_videocd"), action));
 
@@ -604,7 +605,9 @@ void MainWindow::parseArgs(const QString workingDirectory)
 
 void MainWindow::displayModeChanged()
 {
-	switch (mediaWidget->getDisplayMode()) {
+	MediaWidget::DisplayMode displayMode = mediaWidget->getDisplayMode();
+
+	switch (displayMode) {
 	case MediaWidget::FullScreenMode:
 	case MediaWidget::FullScreenReturnToMinimalMode:
 		setWindowState(windowState() | Qt::WindowFullScreen);
@@ -615,7 +618,7 @@ void MainWindow::displayModeChanged()
 		break;
 	}
 
-	switch (mediaWidget->getDisplayMode()) {
+	switch (displayMode) {
 	case MediaWidget::FullScreenMode:
 	case MediaWidget::FullScreenReturnToMinimalMode:
 	case MediaWidget::MinimalMode:
@@ -624,9 +627,6 @@ void MainWindow::displayModeChanged()
 		controlBar->hide();
 		autoHideControlBar = true;
 		cursorHideTimer->start();
-
-		stackedLayout->setCurrentIndex(PlayerTabId);
-		playerTab->activate();
 		break;
 	case MediaWidget::NormalMode:
 		menuBar()->show();
@@ -635,11 +635,9 @@ void MainWindow::displayModeChanged()
 		autoHideControlBar = false;
 		cursorHideTimer->stop();
 		unsetCursor();
-
-		stackedLayout->setCurrentIndex(currentTabIndex);
-		tabs.at(currentTabIndex)->activate();
 		break;
 	}
+	tabs.at(currentTabIndex)->toggleDisplayMode(displayMode);
 }
 
 void MainWindow::trayShowHide(QSystemTrayIcon::ActivationReason reason)
@@ -798,31 +796,51 @@ bool MainWindow::event(QEvent *event)
 	// but the latter depends on mouse tracking being enabled on this widget
 	// and all its children (especially the video widget) ...
 
-	if ((event->type() == QEvent::HoverMove) && autoHideControlBar) {
+	switch (event->type()) {
+	case QEvent::Wheel: {
+		QWheelEvent *wheel = static_cast<QWheelEvent *>(event);
+
+		int delta = (wheel->pixelDelta().y() < 0) ? -1 : 1;
+
+		mediaWidget->setVolume(mediaWidget->getVolume() + delta);
+		break;
+	}
+	case QEvent::HoverMove: {
+		int x = reinterpret_cast<QHoverEvent *> (event)->pos().x();
 		int y = reinterpret_cast<QHoverEvent *> (event)->pos().y();
 
-		if ((y < 0) || (y >= height())) {
+		if ((y < 0) || (y >= height()) ||
+		    (x < 0) || (x >= width())) {
 			// QHoverEvent sometimes reports quite strange coordinates - ignore them
 			return retVal;
 		}
 
-		cursorHideTimer->stop();
-		unsetCursor();
+		if (autoHideControlBar) {
+			cursorHideTimer->stop();
+			unsetCursor();
 
-		switch (toolBarArea(controlBar)) {
-		case Qt::TopToolBarArea:
-			controlBar->setVisible(y < 60);
-			break;
-		case Qt::BottomToolBarArea:
-			controlBar->setVisible(y >= (height() - 60));
-			break;
-		default:
-			break;
+			switch (toolBarArea(controlBar)) {
+			case Qt::TopToolBarArea:
+				controlBar->setVisible(y < 60);
+				break;
+			case Qt::BottomToolBarArea:
+				controlBar->setVisible(y >= (height() - 60));
+				menuBar()->setVisible(y < 60);
+				break;
+			default:
+				break;
+			}
+
+			if (controlBar->isHidden() || menuBar()->isHidden()) {
+				cursorHideTimer->start();
+			}
 		}
 
-		if (controlBar->isHidden()) {
-			cursorHideTimer->start();
-		}
+		tabs.at(currentTabIndex)->mouse_move(x, y);
+		break;
+	}
+	default:
+		break;
 	}
 
 	return retVal;
