@@ -44,6 +44,7 @@ public:
 	~MainWindow();
 
 	void run();
+	void parseArgs(const QString workingDirectory = "");
 
 signals:
 	void mayCloseApplication(bool *ok, QWidget *parent);
@@ -59,7 +60,6 @@ private slots:
 	void openDvd(const QString &device = QString());
 	void playDvdFolder();
 	void playDvb();
-	void resizeToVideo(MediaWidget::ResizeFactor resizeFactor);
 	void configureKeys();
 	void configureKaffeine();
 	void navigationBarOrientationChanged(Qt::Orientation orientation);
@@ -84,7 +84,6 @@ private:
 
 	KAboutData *aboutData;
 	QCommandLineParser *parser;
-	void parseArgs();
 
 	QSystemTrayIcon *trayIcon;
 
