@@ -56,9 +56,14 @@ public:
 	enum AspectRatio
 	{
 		AspectRatioAuto,
+		AspectRatio1_1,
 		AspectRatio4_3,
+		AspectRatio5_4,
 		AspectRatio16_9,
-		AspectRatioWidget
+		AspectRatio16_10,
+		AspectRatio221_100,
+		AspectRatio235_100,
+		AspectRatio239_100,
 	};
 
 	enum DisplayMode
@@ -84,13 +89,6 @@ public:
 		Paused
 	};
 
-	enum ResizeFactor
-	{
-		ResizeOff,
-		OriginalSize,
-		DoubleSize
-	};
-
 	DisplayMode getDisplayMode() const;
 	void setDisplayMode(DisplayMode displayMode_);
 
@@ -150,7 +148,7 @@ public:
 signals:
 	void displayModeChanged();
 	void changeCaption(const QString &caption);
-	void resizeToVideo(MediaWidget::ResizeFactor resizeFactor);
+	void resizeToVideo(float resizeFactor);
 
 	void playlistPrevious();
 	void playlistNext();
@@ -168,6 +166,7 @@ private slots:
 	void seek(int position);
 	void deinterlacingChanged(bool deinterlacing);
 	void aspectRatioChanged(QAction *action);
+	void setVideoSize();
 	void autoResizeTriggered(QAction *action);
 	void pausedChanged(bool paused);
 	void timeButtonClicked();
@@ -232,7 +231,7 @@ private:
 	QPushButton *timeButton;
 
 	DisplayMode displayMode;
-	ResizeFactor automaticResize;
+	int autoResizeFactor;
 	QScopedPointer<MediaSource> dummySource;
 	MediaSource *source;
 	bool blockBackendUpdates;
